@@ -1,6 +1,8 @@
-from .dataLoad.data_loader import DataGetter
+"""
+from dataLoad.data_loader import DataGetter
 from .dataPreprocessing.preProcess import Preprocessor
 from .dataVisualization.visualization import DataVisualization
 from .modelTraining.classificationModels import ClassificationModelTuner
 from .prediction.predict import Prediction
-from .logger.appLogger import AppLogger
\ No newline at end of file
+from .logger.appLogger import AppLogger
+"""
\ No newline at end of file
