@@ -65,11 +65,11 @@ def load_data_from_source():
                                 """
     file = request.files['filename'] #File can be obtained from request.files
     file_type = request.form['source'] #File Source can be obtained here
-    data_getter = DataGetter()  #Class DataGetter object created
+    data_getter = data_loader.DataGetter()  #Class DataGetter object created
     global dataset    #Declare global variable
-    data_getter = DataGetter()  # instantiation for genrating preprocessing logs
+    data_getter =data_loader.DataGetter()  # instantiation for genrating preprocessing logs
     dataset = data_getter.get_data(file_type, file)   #call get_data method, it will load the dataset into dataframe
-    preprocessor = Preprocessor()  # instantiation for genrating preprocessing logs
+    preprocessor = preProcess.Preprocessor()  # instantiation for genrating preprocessing logs
     data_profile = preprocessor.get_data_profile(dataset)  #call get_data_profile
     # print(data.head())
     # render template tables.html with the respective dataset
@@ -95,7 +95,7 @@ def start_processing():
     target_column = request.form['target_column']   #get target column name
     unwanted_cols = request.form['unwanted_cols']   #get unwanted columns
     global x, y
-    preprocessor = Preprocessor()  # instantiation for genrating prediction logs
+    preprocessor = preProcess.Preprocessor()  # instantiation for genrating prediction logs
     x, y = preprocessor.preprocess(dataset, target_column,unwanted_cols)  #Calling preprocess method of preprocessor class
     hmap = visuals.correlation_heatmap(x)
     # problem_type = 'classification'
@@ -158,9 +158,9 @@ def predict():
                                        """
     file = request.files['prediction_filename'] #get prediction file
     file_type = request.form['source']  #get file type
-    data_getter = DataGetter() #declare object for DataGetter class
+    data_getter = data_loader.DataGetter() #declare object for DataGetter class
     global prediction_dataset
-    prediction = Prediction()  # instantiation for genrating prediction log
+    prediction = predict.Prediction()  # instantiation for genrating prediction log
     prediction_dataset = data_getter.get_data(file_type, file) #load file from get_data method
     preds = prediction.predict_results(prediction_dataset,target_column,dataset.columns)  #predict the result for the data loaded
     #render prediction_results.html with the prediction result
