@@ -26,8 +26,8 @@ class ClassificationModelTuner():
         """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/classificationModelsLogs.txt', 'a+')
-        self.logger_object = applogger.AppLogger()
+        self.file_object = open('classificationModelsLogs.txt', 'a+')
+        self.logger_object = appLogger.AppLogger()
         self.file_operation = file_methods.FileOperation()
 
     def get_tuned_random_forest_classifier(self, x_train, y_train):
