@@ -18,7 +18,7 @@ class FileOperation:
                 """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/fileOperationLogs.txt', 'a+')
+        self.file_object = open('fileOperationLogs.txt', 'a+')
         self.logger_object = appLogger.AppLogger()
         self.model_directory = 'models/'
 
