@@ -22,8 +22,8 @@ class Preprocessor():
     """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/dataPreprocessingLogs.txt', 'a+')
-        self.logger_object = applogger.AppLogger()
+        self.file_object = open('dataPreprocessingLogs.txt', 'a+')
+        self.logger_object = appLogger.AppLogger()
 
     def get_data_profile(self, data):
         """
