@@ -30,8 +30,8 @@ class Prediction():
                         Revisions: None
 
                 """
-        self.file_object = open('pneuro/logs/predictionLogs.txt', 'a+')
-        self.logger = applogger.AppLogger()
+        self.file_object = open('predictionLogs.txt', 'a+')
+        self.logger = appLogger.AppLogger()
         self.file_operation = file_methods.FileOperation()
         self.models_directory = 'models'
         self.preprocessor = preProcess.Preprocessor()
