@@ -25,7 +25,7 @@ class DataVisualization:
     """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/dataVisualizationLogs.txt', 'a+')
+        self.file_object = open('dataVisualizationLogs.txt', 'a+')
         self.logger_object = appLogger.AppLogger()
 
     def balance_imbalance_check(self, dataframe, target):
